@@ -12,10 +12,11 @@
 
 #include "LogHandler.h"
 #include "MvQLogBrowser.h"
+#include "MvQTheme.h"
 
-static QColor okBg(230, 231, 232);
-//static QColor errBg(223, 224, 222);
-static QColor titleBg(50, 50, 50);
+static QColor okBg;
+static QColor titleFg;
+static QColor errorFg;
 
 QMap<QString, QString> MvQLogBrowser::keys_;
 
@@ -25,6 +26,12 @@ MvQLogBrowser::MvQLogBrowser(QWidget* parent) :
 {
     setProperty("mvStyle", "log");
 
+    if (!okBg.isValid()) {
+        okBg = MvQTheme::colour("log", "ok_bg");
+        titleFg = MvQTheme::colour("log", "title");
+        errorFg = MvQTheme::colour("log", "error");
+    }
+
     if (keys_.isEmpty()) {
         keys_[QString::fromStdString(GuiLog::commandKey())] = "Command";
         keys_[QString::fromStdString(GuiLog::methodKey())]  = "Method";
@@ -32,7 +39,6 @@ MvQLogBrowser::MvQLogBrowser(QWidget* parent) :
     }
 
     OutputToGui::setObserver(this);
-
     //Set css for the text formatting
     QString cssDoc = "table {margin-top: 1px; margin-bottom: 1px; background-color: " + okBg.name() +
                      ";}  \
@@ -75,7 +81,8 @@ void MvQLogBrowser::update(const std::string& s, metview::Type t)
             p          = "<br>" + creTitle("Output") + " ";
             hasOutput_ = true;
         }
-        txt = p + "<br><font color=\'#C21C1C\'> <b>ERROR</b> - " + txt + "</font>";
+        txt = p + "<br><font color=\'" + errorFg.name()+
+            "\'> <b>ERROR</b> - " + txt + "</font>";
     }
     else {
         QString p;
@@ -109,41 +116,9 @@ void MvQLogBrowser::parseTask(QString t, QString& desc, QString& cmd, QString& c
 
 QString MvQLogBrowser::creTitle(QString t)
 {
-    return "<b><font color=\'" + titleBg.name() + "\'>" + t + ": </font></b>";
+    return "<b><font color=\'" + titleFg.name() + "\'>" + t + ": </font></b>";
 }
 
-#if 0
-QString MvQLogBrowser::creIconCell(int iconSize,QString iconPath)
-{
-    return "<td width=\'" + QString::number(iconSize+8) + "\'><img src=\'" + iconPath +
-            "\' width=\'" +   QString::number(iconSize) + "\'" +
-            "\' height=\'" +   QString::number(iconSize) + "\'></td>";
-}
-
-QString MvQLogBrowser::creError()
-{
-    QString t=toHtml();
-    qDebug() << t;
-    int i=t.lastIndexOf("<table");
-    if(i != -1)
-    {
-         QString t1=t.left(i);
-         QString t2=t.mid(i,-1);
-
-         qDebug() << "t1" << t1;
-         qDebug() << "t2" << t2;
-
-         t2.replace("log_info.svg","log_error.svg");
-
-         qDebug() << "t2" << t2;
-
-         return t1 + t2;
-    }
-    return QString();
-}
-
-#endif
-
 void MvQLogBrowser::slotTextChanged()
 {
     if (hasOutput_ && document()->isEmpty())
