@@ -37,10 +37,13 @@
 
 #include <QDebug>
 
-ExportDialog::ExportDialog(int currentFrame, int totalFrames, const string& sdir, QWidget* parent) :
+ExportDialog::ExportDialog(int currentFrame, int totalFrames,
+                           const string& sdir, bool export_qt,
+                           QWidget* parent) :
     QFileDialog(parent, "Export"),
     current_(currentFrame),
-    total_(totalFrames)
+    total_(totalFrames),
+    export_qt_(export_qt)
 {
     // Set widget mode behaviour to "Save As"
     this->setAcceptMode(QFileDialog::AcceptSave);
@@ -97,14 +100,21 @@ ExportDialog::ExportDialog(int currentFrame, int totalFrames, const string& sdir
 
     // Retrieve and save the list of output formats from the resources file
     comboBox_ = new QComboBox(this);
-    ObjectList::FindAll("output_format", reqFormats_);
+    if (export_qt_)
+        ObjectList::FindAll("output_format_qt", reqFormats_);
+    else
+        ObjectList::FindAll("output_format", reqFormats_);
     int index = 0;
     while (reqFormats_) {
         // Add output format to the user interface
         comboBox_->insertItem(index++, (const char*)reqFormats_("class"));
         reqFormats_.advance();
     }
-    comboBox_->setCurrentIndex(fIndex);
+
+    if (fIndex < comboBox_->count())
+        comboBox_->setCurrentIndex(fIndex);
+    else
+        comboBox_->setCurrentIndex(0);
 
     // Build the Edit button
     bEdit_ = new QToolButton(this);
@@ -123,7 +133,9 @@ ExportDialog::ExportDialog(int currentFrame, int totalFrames, const string& sdir
     connect(bEdit_, SIGNAL(clicked()), this, SLOT(slotEditFormat()));
 
     // Build Frame Selection widget
-    buildFrameSelection(row - 2, col - 1, mainLayout, frameSelRB, frameSelLE);
+    bool enabled = !export_qt_;
+    buildFrameSelection(row - 2, col - 1, mainLayout, frameSelRB, frameSelLE,
+                        enabled);
 
     // Move Save and Cancel buttons to the bottom.
     // Save and Cancel buttons are defined together in a QDialogButtonBox.
@@ -205,7 +217,11 @@ void ExportDialog::slotEditFormat()
     string format = comboBox_->currentText().toStdString();
 
     // Get output format request
-    MvRequest reqFormat = ObjectList::Find("output_format", format.c_str());
+    MvRequest reqFormat;
+    if (export_qt_)
+        reqFormat = ObjectList::Find("output_format_qt", format.c_str());
+    else
+        reqFormat = ObjectList::Find("output_format", format.c_str());
 
     // Read the selected output format request from the Metview/Defaults directory.
     // If not found, create a default request
@@ -262,7 +278,8 @@ void ExportDialog::slotRangeFrameSelection(bool checked)
 void ExportDialog::buildFrameSelection(int row, int col,
                                        QGridLayout* mainLayout,
                                        const std::vector<bool>& frameSelRB,
-                                       const QString& frameSelLE)
+                                       const QString& frameSelLE,
+                                       bool enabled)
 {
     // Group Box with radio buttons and one line edit
     QGroupBox* gbFs = new QGroupBox(tr("Frame Selection"), this);
@@ -299,6 +316,9 @@ void ExportDialog::buildFrameSelection(int row, int col,
     // Conexions
     connect(cbFs3_, SIGNAL(toggled(bool)), this, SLOT(slotRangeFrameSelection(bool)));
 
+    // Set widget enabled/not enabled
+    gbFs->setEnabled(enabled);
+
     // Attach widget to the parent
     mainLayout->addWidget(gbFs, row, col, 3, 1);
 }
