@@ -188,8 +188,9 @@ const WeightMatrix& MethodWeighted::getMatrix(context::Context& ctx, const repre
     here = timer.elapsed();
     WeightMatrix W(out.numberOfPoints(), in.numberOfPoints());
 
-    bool caching = true;
+    bool caching = LibMir::caching();
     parametrisation_.get("caching", caching);
+
     if (caching) {
 
         // The WeightCache is parametrised by 'caching',
@@ -331,7 +332,8 @@ void MethodWeighted::execute(context::Context& ctx, const repres::Representation
 
     // ensure unique missingValue on no input missing values
     data::MIRField& field = ctx.field();
-    if (!field.hasMissing()) {
+    const bool hasMissing = field.hasMissing();
+    if (!hasMissing) {
         field.missingValue(std::numeric_limits<double>::lowest());
     }
 
@@ -359,7 +361,7 @@ void MethodWeighted::execute(context::Context& ctx, const repres::Representation
 
         // Get input/output matrices
         std::string space;
-        parametrisation_.get("space", space);
+        parametrisation_.get("vector-space", space);
         const data::Space& sp = data::SpaceChooser::lookup(space);
 
         MIRValuesVector result(npts_out);  // field.update() takes ownership with std::swap()
@@ -400,7 +402,7 @@ void MethodWeighted::execute(context::Context& ctx, const repres::Representation
         for (auto& r : forceMissing) {
             result[r] = missingValue;
         }
-        field.update(result, i);
+        field.update(result, i, hasMissing || !forceMissing.empty());
 
 
         if (check_stats) {
